@@ -13,6 +13,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 """
-`bq-validator` enables us to validate BigQuery queries.
+The `bq-validator` command enables us to validate BigQuery queries.
 """
-__version__ = "0.1.0"
+__version__ = "0.2.0"
